@@ -14,12 +14,13 @@ from ansurr import compare
 from ansurr import cyrange
 from ansurr import plot2D
 from ansurr import dssp
+from ansurr import export_nef
 
 from ansurr.functions import check_quiet_print
 from datetime import datetime
 
 sys.tracebacklimit = 0
-version = "0.0.40"
+ansurr_version = "0.0.42"
 
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
@@ -35,7 +36,7 @@ def main():
     parser.add_argument("-q", "--quiet", help="supress output to the terminal", action="store_true")
     parser.add_argument("-r", "--reref", help="re-reference shifts using PANAV before calculating RCI (requires Java)",action="store_true")
     parser.add_argument("-w", "--welldef", help="compute ANSURR scores for only well-defined residues identified by CYRANGE", action="store_true")
-    parser.add_argument("-v", "--version", action='version', version='\nANSURR | Accuracy of NMR Structures Using RCI and Rigidity v'+version+' | citation: https://doi.org/10.1038/s41467-020-20177-1')
+    parser.add_argument("-v", "--version", action='version', version='\nANSURR | Accuracy of NMR Structures Using RCI and Rigidity v'+ansurr_version+' | citation: https://doi.org/10.1038/s41467-020-20177-1')
     args = parser.parse_args()
 
     path_to_shifts = args.shifts
@@ -45,7 +46,7 @@ def main():
     pdb_file = os.path.basename(os.path.splitext(path_to_pdb)[0])
 
     now = datetime.now()
-    check_quiet_print(args.quiet,"ANSURR v"+version+" "+now.strftime("%d/%m/%Y %H:%M:%S"))
+    check_quiet_print(args.quiet,"ANSURR v"+ansurr_version+" "+now.strftime("%d/%m/%Y %H:%M:%S"))
     check_quiet_print(args.quiet," -> pdb: "+path_to_pdb)
     check_quiet_print(args.quiet," -> shifts: "+path_to_shifts)
 
@@ -64,7 +65,7 @@ def main():
     os.makedirs(output_dir)   
 
     check_quiet_print(args.quiet,"calculating RCI")
-    chain_output_rci = rci_nef.calc_RCI(path_to_shifts,output_dir+'/other_output/',panav=args.reref,quiet=args.quiet)
+    set_chain_output_rci = rci_nef.calc_RCI(path_to_shifts,output_dir+'/other_output/',panav=args.reref,quiet=args.quiet)
 
     check_quiet_print(args.quiet,'extracting models from '+path_to_pdb)
     pdbs,args.oligomer  = rigidipy.extract_pdb(path_to_pdb,output_dir,freeligands=args.lig,nonstandardres=args.nonstd,oligomers=args.olig,quiet=args.quiet)
@@ -119,15 +120,22 @@ def main():
 
     check_quiet_print(args.quiet,'computing ANSURR scores')
 
+    nef_output = {'per_model':{},'per_residue':{}}
     for chain in chain_output_rigidity:
         for rigidity in sorted(chain_output_rigidity[chain],key=natsort):
-            if chain in chain_output_rci:
-                for rci in sorted(chain_output_rci[chain],key=natsort):
-                    compare.compare_rci_rigidity(rigidity,rci,output_dir,cyrange=args.welldef,quiet=args.quiet)
-            else:
-                for rci_chain in sorted(chain_output_rci,key=natsort):
-                    for rci in chain_output_rci[rci_chain]:
-                        compare.compare_rci_rigidity(rigidity,rci,output_dir,cyrange=args.welldef,quiet=args.quiet)  
+            found = 0
+            for rci_set in set_chain_output_rci:
+                if chain in set_chain_output_rci[rci_set]:
+                    for rci in sorted(set_chain_output_rci[rci_set][chain],key=natsort):
+                        nef_output = compare.compare_rci_rigidity(rigidity,rci,pdb_chain=chain,rci_set=rci_set,rci_chain=chain,nef_output=nef_output,output_dir=output_dir,cyrange=args.welldef,quiet=args.quiet)
+                        found = 1
+            if found == 0:  
+                for rci_set in set_chain_output_rci:
+                    for rci_chain in sorted(set_chain_output_rci[rci_set],key=natsort):
+                        for rci in set_chain_output_rci[rci_set][rci_chain]:
+                            nef_output = compare.compare_rci_rigidity(rigidity,rci,pdb_chain=chain,rci_set=rci_set,rci_chain=rci_chain,nef_output=nef_output,output_dir=output_dir,cyrange=args.welldef,quiet=args.quiet)  
+        
+    export_nef.export(nef_output,output_dir=output_dir+'/ANSURR_output/'+pdb_file+'_'+shift_file,ansurr_version=ansurr_version,pdb_file=os.path.basename(path_to_pdb),shift_file=os.path.basename(path_to_shifts),reref=args.reref,lig=args.lig,nonstd=args.nonstd,olig=args.olig)
 
     if len(glob.glob(output_dir+'/ANSURR_output/out/*.out')) > 0:
         if os.path.exists(output_dir+'/ANSURR_output/scores.out'):
